==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSU_subs_help.h <==
/* $Date: 1996/09/18 15:02:44 $  $Author: andi $  $Revision: 1.2 $ */

/**************************************************************************/
/* FILE:             MSU_subs_help.h  	                                  */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         10/12/91                                             */
/* Letzte Aenderung: 20/08/93                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen des Modules MSU_subs_help       */
/**************************************************************************/

#ifndef __MSU_eval_subs_help__
#define __MSU_eval_subs_help__


#ifdef MDX

#define MSUC_SCAN_ALL   1L
#define MSUC_SCAN_POS   2L
#define MSUC_SCAN_FIRST 3L

MUPbool    MSU_is_stmtseq	( S_Pointer	 t, 
				  long		*pos,
				  long		 scan_mode );

S_Pointer MSU_remove_debug_info ( S_Pointer     t );

#endif /* MDX */


void       MSU_check_range	( S_Pointer	 s, 
				  long		*lb, 
				  long		*ub,
				  char	        *fname );
S_Pointer *MSU_get_operand	( S_Pointer	*t, 
				  long		 ind,
				  long		*error_flag );
void       MSU_check_equation	( S_Pointer	 s,
				  S_Pointer	*spec, 
				  S_Pointer	*neww,
				  char	        *fname );
S_Pointer  MSU_build_range	( long		 i, 
				  long		 j );
#ifdef DEADCODE
S_Pointer  MSU_check_func_env	( S_Pointer	 s );
#endif
long       MSU_specialMINUS2expr( S_Pointer	*t,
				  long		 change );
long       MSU_specialDIV2expr	( S_Pointer	*t,
				  long		 change );
long       MSU_specialNOT2expr	( S_Pointer	*t,
				  long		 change );


#endif /* __MSU_eval_subs_help__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSU_subs_help.h <==
/* $Date: 1999/06/02 07:22:17 $  $Author: kg $  $Revision: 1.4 $ */

/**************************************************************************/
/* FILE:             MSU_subs_help.h  	                                  */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         10/12/91                                             */
/* Letzte Aenderung: 20/08/93                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen des Modules MSU_subs_help       */
/**************************************************************************/

#ifndef __MSU_eval_subs_help__
#define __MSU_eval_subs_help__


#ifdef MDX

#define MSUC_SCAN_ALL   1
#define MSUC_SCAN_POS   2
#define MSUC_SCAN_FIRST 3

bool    MSU_is_stmtseq	( S_Pointer	 t,
				  long		*pos,
				  long		 scan_mode );

S_Pointer MSU_remove_debug_info ( S_Pointer     t );

#endif /* MDX */


void       MSU_check_range	( S_Pointer	 s,
				  long		*lb,
				  long		*ub,
				  char	        *fname );
S_Pointer *MSU_get_operand	( S_Pointer	*t,
				  long		 ind,
				  long		*error_flag );
void       MSU_check_equation	( S_Pointer	 s,
				  S_Pointer	*spec,
				  S_Pointer	*neww,
				  char	        *fname );
S_Pointer  MSU_build_range	( long		 i,
				  long		 j );
#ifdef DEADCODE
S_Pointer  MSU_check_func_env	( S_Pointer	 s );
#endif
long       MSU_specialMINUS2expr( S_Pointer	*t,
				  long		 change );
long       MSU_specialDIV2expr	( S_Pointer	*t,
				  long		 change );
long       MSU_specialNOT2expr	( S_Pointer	*t,
				  long		 change );


#endif /* __MSU_eval_subs_help__ */
